%def_enable tui
%def_with debuginfod
%def_disable check
%def_with python
%def_enable gdbserver

Name: gdb
Version: 14.1.0.56.d739d4fd457
Release: alt1

Summary: A GNU source-level debugger for C, C++ and other languages
License: GPLv3+
Group: Development/Debuggers
Url: http://www.gnu.org/software/gdb/

# http://git.altlinux.org/gears/g/gdb.git
Source: gdb-%version-%release.tar

BuildRequires(pre): rpm-build-python3
BuildRequires: flex libreadline-devel libexpat-devel liblzma-devel zlib-devel libgmp-devel libmpfr-devel
BuildRequires: gcc-c++
BuildRequires: makeinfo
BuildRequires: %{?_with_python:python3-devel} %{?_enable_tui:libncursesw-devel} %{?_with_debuginfod:libdebuginfod-devel}
%{?!_without_check:%{?!_disable_check:BuildRequires: dejagnu glibc-devel-static gcc-c++ gcc-fortran gcc-objc prelink valgrind /proc /dev/pts}}
Requires: gdb-common = %version-%release

%description
GDB is a full featured, command driven debugger.  GDB allows you to
trace the execution of programs and examine their internal state at
any time.  The debugger is most effective when used together with a
supported compiler, such as those from the GNU Compiler Collection.

%package -n gdbserver
Summary: A standalone server for GDB (the GNU source-level debugger)
Group: Development/Debuggers

%description -n gdbserver
GDB, the GNU debugger, allows you to debug programs written in C, C++,
Java, and other languages, by executing them in a controlled fashion and
printing their data.
This package provides a program that allows you to run GDB on a
different machine than the one which is running the program being
debugged.


%package light
Summary: A GNU source-level debugger for C, C++ and other languages (light build)
Group: Development/Debuggers
Requires: gdb-common = %version-%release
Conflicts: gdb < 7.5.0.20121002-alt5

%description light
GDB is a full featured, command driven debugger.  GDB allows you to
trace the execution of programs and examine their internal state at
any time.  The debugger is most effective when used together with a
supported compiler, such as those from the GNU Compiler Collection.
This package contains light build of GDB without expat, python and
tui support.

%package common
Summary: GDB common files
Group: Development/Debuggers
BuildArch: noarch
Conflicts: gdb < 7.5.0.20121002-alt5

%description common
This package contains common GDB files.

%package -n libgdb-devel
Summary: GDB static libraries
Group: Development/C
Conflicts: libbfd-devel libiberty-devel

%description -n libgdb-devel
This package contains static GDB libraries required to build other debuggers.

%prep
%setup -n %name-%version-%release
# Remove generated bison and flex parser files.
egrep -lZ 'A (Bison parser, made by GNU Bison|lexical scanner generated by flex)' gdb/*.c |
	xargs -r0 rm --

# Somehow readline/doc is needed to build other docs.
mv readline/readline/doc readline-doc

# We want to use these as system libraries.
rm -r readline zlib

find -type f -name \*.orig -delete
xz -9k gdb/{MAINTAINERS,NEWS}

%build
echo '%version-%release (%distribution)' >gdb/version.in

for f in */configure.ac; do
	pushd "${f%%/*}"
		[ configure.in -nt configure ] && autoconf
	popd
done
for f in */Makefile.am; do
	pushd "${f%%/*}"
		[ Makefile.am -nt Makefile.in ] && automake
	popd
done

%define _configure_script ../configure

set -- \
	--with-gdb-datadir=%_datadir/gdb \
	--with-separate-debug-dir=/usr/lib/debug \
	--with-auto-load-dir='$debugdir:%_libdir/gdb/auto-load:$datadir/auto-load' \
	--enable-gdb-build-warnings=,-Wno-unused \
	--disable-werror \
	--disable-sim \
	--disable-rpath \
	--with-system-readline \
	--with-lzma \
	--without-libexpat-prefix \
	--without-libunwind \
	--enable-64-bit-bfd \
	--with-system-zlib \
	#

export \
	ac_cv_have_x=${ac_cv_have_x='have_x=yes ac_x_includes=%_x11includedir ac_x_libraries=%_x11libdir'} \
	%{?!_enable_tui:ac_cv_search_tgetent='none required'} \
	#

%define buildtarget build-%_target
rm -rf %buildtarget
mkdir %buildtarget
pushd %buildtarget

%{?optflags_lto:%global optflags_lto %optflags_lto -ffat-lto-objects}

%configure \
	"$@" \
	%{subst_enable tui} \
	%{subst_with debuginfod} \
%if_with python
	--with-python=python3 \
%endif
	#

%make_build
%make_build -C gdb libgdb.a
%make_build info MAKEINFOFLAGS=--no-split

popd #%buildtarget

rm -rf light
mkdir light
pushd light

%configure \
	"$@" \
	--disable-tui \
	--without-expat \
	--without-python \
	--without-debuginfod \
	#
%make_build

popd #light

%install
%makeinstall_std -C %buildtarget
install -pm755 light/gdb/gdb %buildroot%_bindir/gdb-light

install -pm644 alt/gdb-gstack.man %buildroot%_man1dir/gstack.1

# These files are already packaged as a part of binutils.
rm %buildroot%_infodir/bfd*
rm %buildroot%_infodir/ctf*
rm %buildroot%_infodir/sframe*
rm %buildroot%_datadir/locale/*/LC_MESSAGES/{bfd,opcodes}.mo

pushd %buildtarget
mkdir -p %buildroot%_libdir
install -pm644 */lib*.a %buildroot%_libdir/
popd #%buildtarget

mkdir -p %buildroot%_datadir/gdb/auto-load

rm %buildroot/%_datadir/gdb/system-gdbinit/elinos.py
rm %buildroot/%_datadir/gdb/system-gdbinit/wrs-linux.py
rmdir %buildroot/%_datadir/gdb/system-gdbinit

# These are provided by the gdb binary.
%add_python3_req_skip _gdb
%add_python3_req_skip _gdbevents
%add_python3_req_skip _gdb.disassembler
%add_python3_path %_datadir/gdb/python

%set_verify_elf_method strict
%define _unpackaged_files_terminate_build 1
%define _stripped_files_terminate_build 1

%check
[ -w /dev/ptmx -a -f /proc/self/maps ] || exit
pushd %buildtarget/gdb
cc %optflags -o orphanripper alt/gdb-orphanripper.c -lutil
./orphanripper make -k -j%__nprocs check ||:
popd

%pre
# gdb-8.2.50.20180917-alt1 switched from a symlink (to Python2 site-libdir)
# to a normal directory (with Python3 code). Give way to the directory:
l=%_datadir/gdb/python/gdb
if [ -L "$l" ]; then
    rm -v "$l"
fi

%files
%_bindir/*
%if_with python
%_datadir/gdb/python
%endif
%exclude %_bindir/gdb-light
%if_enabled gdbserver
%exclude %_bindir/gdbserver

%files -n gdbserver
%_bindir/gdbserver
# no ipa_obj for arm* and mips*
%ifnarch armh %mips loongarch64
%_libdir/libinproctrace.so
%endif
%endif

%files light
%_bindir/gdb-light

%files common
%_man1dir/*
%_infodir/*
%_datadir/gdb
%doc gdb/{MAINTAINERS,NEWS}.xz
%exclude %_datadir/gdb/python

%files -n libgdb-devel
%_includedir/*
%_libdir/lib*.a

%changelog
* Wed Jan 24 2024 Gleb F-Malinovskiy <glebfm@altlinux.org> 14.1.0.56.d739d4fd457-alt1
- Updated to gdb-14.1-release-56-gd739d4fd457.

* Wed Sep 27 2023 Alexey Sheplyakov <asheplyakov@altlinux.org> 13.2.0.43.854f46b6377-alt3
- NMU: fixed FTBFS on LoongArch (in process tracing is not supported).

* Sat Sep 23 2023 Gleb F-Malinovskiy <glebfm@altlinux.org> 13.2.0.43.854f46b6377-alt2
- Backported upstream commit to fix build with texinfo >= 7 (thx Enze Li).

* Wed Aug 23 2023 Gleb F-Malinovskiy <glebfm@altlinux.org> 13.2.0.43.854f46b6377-alt1
- Updated to gdb-13.2-release-43-g854f46b6377.
- Enabled the gdbserver on riscv64 architecture, it is supported upstream
  since gdb 10.1.

* Sun Feb 06 2022 Gleb F-Malinovskiy <glebfm@altlinux.org> 11.2-alt1
- Updated to gdb-11.2-release.

* Sat Feb 05 2022 Gleb F-Malinovskiy <glebfm@altlinux.org> 11.1-alt2
- Synced with Fedora binutils 11.1-12.
- Backported upstream commits for glibc 2.35 support.

* Sat Oct 30 2021 Gleb F-Malinovskiy <glebfm@altlinux.org> 11.1-alt1
- Fixed build with LTO flags.
- Updated to 11.1.

* Tue Nov 10 2020 Gleb F-Malinovskiy <glebfm@altlinux.org> 10.1-alt1
- Updated to 10.1.
- Built with debuginfod support.

* Mon Oct 26 2020 Gleb F-Malinovskiy <glebfm@altlinux.org> 8.3-alt3
- Applied upstream patch (ALT#39135) (fixes CVE-2019-1010180).

* Wed Mar 11 2020 Sergey Bolshakov <sbolshakov@altlinux.ru> 8.3-alt2
- fix packaging on armh arch

* Wed Jul 31 2019 Gleb F-Malinovskiy <glebfm@altlinux.org> 8.3-alt1
- Updated to 8.3.

* Tue Jul 09 2019 Ivan A. Melnikov <iv@altlinux.org> 8.2.50.20180917-alt5
- Fix build on mips.

* Thu Jun 27 2019 Ivan Zakharyaschev <imz@altlinux.org> 8.2.50.20180917-alt4
- %%pre: corrected the old symlink path in 8.2.50.20180917-alt3.

* Wed Jun 26 2019 Ivan Zakharyaschev <imz@altlinux.org> 8.2.50.20180917-alt3
- %%pre: rm symlink to upgrade from gdb < 8.2.50.20180917-alt1. This works
  for rpm-4.0.4 (when upgrading from p8 to Sisyphus or p9), not for rpm-4.13.

* Wed Nov 21 2018 Nikita Ermakov <arei@altlinux.org> 8.2.50.20180917-alt2
- Disabled gdbserver for RISC-V (riscv64) architecture (not supported yet).

* Mon Oct 08 2018 Gleb F-Malinovskiy <glebfm@altlinux.org> 8.2.50.20180917-alt1
- Updated to 8.2.50.20180917, synced with Fedora 8.2.50.20181006-4.

* Mon Jun 19 2017 Aleksei Nikiforov <darktemplar@altlinux.org> 7.9-alt4
- Fix build with modern glibc by syncing header definitions

* Mon Aug 29 2016 Andrey Cherepanov <cas@altlinux.org> 7.9-alt3
- Do not distribute desktop file for console program

* Thu Dec 10 2015 Andrey Cherepanov <cas@altlinux.org> 7.9-alt2
- Fix configure by adding makeinfo to build requirements
- Rebuild fixes redundant repl_strstr function in libgdb.a

* Tue Sep 08 2015 Sergey Bolshakov <sbolshakov@altlinux.ru> 7.9-alt1
- 7.9 released, synced with fedora 7.9-11

* Thu Jan 30 2014 Evgeny Sinelnikov <sin@altlinux.ru> 7.5.0.20121002-alt5
- Built with python support (closes: #29759).
- Added separate subpackages gdb-common and gdb-light.
- Changed default auto-load path to /usr/share/gdb directory.

* Tue Nov 19 2013 Gleb F-Malinovskiy <glebfm@altlinux.org> 7.5.0.20121002-alt4
- Fixed build with readline6.

* Fri Feb 15 2013 Dmitry V. Levin <ldv@altlinux.org> 7.5.0.20121002-alt3
- Packaged a lightweigted build of gdb as %_bindir/gdb-light.

* Wed Oct 10 2012 Dmitry V. Levin <ldv@altlinux.org> 7.5.0.20121002-alt2
- Disabled few patches that appeared to be too Fedora specific (closes: #27818).

* Fri Oct 05 2012 Dmitry V. Levin <ldv@altlinux.org> 7.5.0.20121002-alt1
- Updated to 7.5.0.20121002, synced with Fedora and Debian.

* Sat Oct 22 2011 Vitaly Kuznetsov <vitty@altlinux.ru> 7.2-alt2.1
- Rebuild with Python-2.7

* Fri Jun 03 2011 Dmitry V. Levin <ldv@altlinux.org> 7.2-alt2
- Updated desktop categories.

* Tue Feb 01 2011 Dmitry V. Levin <ldv@altlinux.org> 7.2-alt1
- Updated to 7.2, synced with FC gdb-7.2-40 and Debian gdb-7.2-1.
- Changed debug dir from %%_libdir/debug to /usr/lib/debug.

* Fri Oct 15 2010 Kirill A. Shutemov <kas@altlinux.org> 7.0.1-alt3
- Set gdb_datadir to %%_libdir/gdb to move auto-load directory out
  of /usr/share.
- Drop libstdc++ helpers: packaged from gcc now.

* Sun Apr 11 2010 Dmitry V. Levin <ldv@altlinux.org> 7.0.1-alt2
- libgdb-devel: Packaged libdecnumber.a.
- Fixed "gdb --version" output.

* Sun Mar 07 2010 Dmitry V. Levin <ldv@altlinux.org> 7.0.1-alt1
- Updated to 7.0.1 (closes: #19417, #20569, #21761).
- Imported bunch of patches from FC gdb-7.0.1-33.
- Imported bunch of patches from Debian gdb-7.0.1-2.

* Mon Mar 03 2008 Dmitry V. Levin <ldv@altlinux.org> 6.6-alt3
- Fixed build with fresh makeinfo.

* Fri Nov 16 2007 Dmitry V. Levin <ldv@altlinux.org> 6.6-alt2
- Packaged static gdb libraries into libgdb-devel subpackage (at@, #8899).

* Sun Apr 01 2007 Dmitry V. Levin <ldv@altlinux.org> 6.6-alt1
- Updated to 6.6.
- Imported bunch of patches from FC gdb-6.6-8.
- Imported bunch of patches from Debian gdb-6.6.dfsg-1.

* Fri Dec 30 2005 ALT QA Team Robot <qa-robot@altlinux.org> 6.3-alt2.1
- Rebuilt with libreadline.so.5.

* Sun May 29 2005 Dmitry V. Levin <ldv@altlinux.org> 6.3-alt2
- Imported bunch of patches from Debian.
- Applied upstream fix to BFD library (CAN-2005-1704).
- Applied fix for .gdbinit issue (CAN-2005-1705).

* Mon Dec 20 2004 Dmitry V. Levin <ldv@altlinux.org> 6.3-alt1
- Updated to 6.3, updated patches.

* Wed Aug 04 2004 Dmitry V. Levin <ldv@altlinux.org> 6.2-alt1
- Updated to 6.2, updated patches.

* Tue Apr 06 2004 Dmitry V. Levin <ldv@altlinux.org> 6.1-alt1
- Updated to 6.1, updated patches.
- Applied patches from RH's gdb-6.0post-0.20040223.8
- Build with bundled libbfd, libopcodes and libiberty.
- Packaged gcore script.
- Enabled tui by default.

* Sun Aug 10 2003 Dmitry V. Levin <ldv@altlinux.org> 5.3-alt2
- Rebuilt with libbfd-2.14.90.0.5.

* Fri Jun 20 2003 Dmitry V. Levin <ldv@altlinux.org> 5.3-alt1
- Updated to 5.3, rediffed patches.
- Merged with gdb-5.3-23mdk (8 patches added).

* Tue Oct 08 2002 Dmitry V. Levin <ldv@altlinux.org> 5.2.1-alt2
- Avoid build dependencies on XFree86-* (#0001376).
- Fixed build with new rpm-build.

* Mon Aug 26 2002 Dmitry V. Levin <ldv@altlinux.org> 5.2.1-alt1
- 5.2.1
- Patched to link with libtinfo.
- Applied "rh-misc" patch from rh gdb-5.2.1-3.

* Mon Jun 17 2002 Dmitry V. Levin <ldv@altlinux.org> 5.2-alt1
- 5.2
- Built with system libreadline, libbfd, libopcodes and libiberty.

* Thu Feb 14 2002 Dmitry V. Levin <ldv@alt-linux.org> 5.1.1-alt1
- Added menu entry.
- Moved mmaloc to separate subpackage.
- Usual ALT adaptions.

* Thu Jan 24 2002 Trond Eivind Glomsrød <teg@redhat.com> 5.1.1-1
- 5.1.1
- add URL

* Wed Jan 09 2002 Tim Powers <timp@redhat.com>
- automated rebuild

* Mon Dec 10 2001 Trond Eivind Glomsrød <teg@redhat.com> 5.1-2
- Fix some thread+fpu problems

* Mon Nov 26 2001 Trond Eivind Glomsrød <teg@redhat.com> 5.1-1
- 5.1

* Mon Nov 19 2001 Trond Eivind Glomsrød <teg@redhat.com> 5.0.94-0.71
- 5.0.94. Almost there....

* Mon Nov 12 2001 Trond Eivind Glomsrød <teg@redhat.com> 5.0.93-2
- Add patch from jakub@redhat.com to improve handling of DWARF

* Mon Nov 12 2001 Trond Eivind Glomsrød <teg@redhat.com> 5.0.93-1
- 5.0.93
- handle missing info pages in post/pre scripts

* Wed Oct 31 2001 Trond Eivind Glomsrød <teg@redhat.com> 5.0.92-1
- 5.0.92

* Fri Oct 26 2001 Trond Eivind Glomsrød <teg@redhat.com> 5.0.91rh-1
- New snapshot
- Use the 5.0.91 versioning from the snapshot

* Wed Oct 17 2001 Trond Eivind Glomsrød <teg@redhat.com> 5.0rh-17
- New snapshot

* Thu Sep 27 2001 Trond Eivind Glomsrød <teg@redhat.com>
- New snapshot

* Wed Sep 12 2001 Trond Eivind Glomsrød <teg@redhat.com> 5.0rh-16
- New snapshot

* Mon Aug 13 2001 Trond Eivind Glomsrød <teg@redhat.com> 5.0rh-15
- Don't buildrequire compat-glibc (#51690)

* Thu Aug  9 2001 Trond Eivind Glomsrød <teg@redhat.com>
- New snapshot, from the stable branch eventually leading to gdb 5.1

* Mon Jul 30 2001 Trond Eivind Glomsrød <teg@redhat.com>
- s/Copyright/License/
- Add texinfo to BuildRequires

* Mon Jun 25 2001 Trond Eivind Glomsrød <teg@redhat.com>
- New snapshot

* Fri Jun 15 2001 Trond Eivind Glomsrød <teg@redhat.com>
- New snapshot
- Add ncurses-devel to buildprereq
- Remove perl from buildprereq, as gdb changed the way
  version strings are generated

* Thu Jun 14 2001 Trond Eivind Glomsrød <teg@redhat.com>
- New snapshot

* Wed May 16 2001 Trond Eivind Glomsrød <teg@redhat.com>
- New snapshot - this had thread fixes for curing #39070
- New way of specifying version

* Tue May  1 2001 Trond Eivind Glomsrød <teg@redhat.com>
- New tarball
- Kevin's patch is now part of gdb

* Mon Apr  9 2001 Trond Eivind Glomsrød <teg@redhat.com>
- Add patch from kevinb@redhat.com to fix floating point + thread
  problem (#24310)
- remove old workarounds
- new snapshot

* Thu Apr  5 2001 Trond Eivind Glomsrød <teg@redhat.com>
- New snapshot

* Sat Mar 17 2001 Bill Nottingham <notting@redhat.com>
- on ia64, there are no old headers :)

* Fri Mar 16 2001 Trond Eivind Glomsrød <teg@redhat.com>
- build with old headers, new compiler

* Wed Mar 16 2001 Trond Eivind Glomsrød <teg@redhat.com>
- new snapshot

* Mon Feb 26 2001 Trond Eivind Glomsrød <teg@redhat.com>
- new snapshot which should fix some more IA64 problems (#29151)
- remove IA64 patch, it's now integrated

* Wed Feb 21 2001 Trond Eivind Glomsrød <teg@redhat.com>
- add IA64 and Alpha patches from Kevin Buettner <kevinb@redhat.com>
- use perl instead of patch for fixing the version string

* Tue Feb 20 2001 Trond Eivind Glomsrød <teg@redhat.com>
- don't use kgcc anymore
- mark it as our own version
- new snapshot

* Mon Jan 22 2001 Bernhard Rosenkraenzer <bero@redhat.com>
- Link with ncurses 5.x even though we're using kgcc.
  No need to drag in requirements on ncurses4 (Bug #24445)

* Fri Jan 19 2001 Trond Eivind Glomsrød <teg@redhat.com>
- new snapshot

* Thu Dec 20 2000 Trond Eivind Glomsrød <teg@redhat.com>
- new snapshot

* Mon Dec 04 2000 Trond Eivind Glomsrød <teg@redhat.com>
- new snapshot
- new alpha patch - it now compiles everywhere. Finally.

* Fri Dec 01 2000 Trond Eivind Glomsrød <teg@redhat.com>
- new snapshot

* Mon Nov 20 2000 Trond Eivind Glomsrød <teg@redhat.com>
- new CVS snapshot
- disable the patches
- don't use %%configure, as it confuses the autoconf script
- enable SPARC, disable Alpha

* Wed Aug 09 2000 Trond Eivind Glomsrød <teg@redhat.com>
- added patch from GDB team for C++ symbol handling

* Mon Jul 25 2000 Trond Eivind Glomsrød <teg@redhat.com>
- upgrade to CVS snapshot
- excludearch SPARC, build on IA61

* Wed Jul 19 2000 Trond Eivind Glomsrød <teg@redhat.com>
- rebuild

* Thu Jul 13 2000 Prospector <bugzilla@redhat.com>
- automatic rebuild

* Sun Jul 02 2000 Trond Eivind Glomsrød <teg@redhat.com>
- rebuild

* Fri Jun 08 2000 Trond Eivind Glomsrød <teg@redhat.com>
- use %%configure, %%makeinstall, %%{_infodir}, %%{_mandir},
  and %%{_tmppath}
- the install scripts  for info are broken(they don't care about
  you specify in the installstep), work around that.
- don't build for IA64

* Mon May 22 2000 Trond Eivind Glomsrød <teg@redhat.com>
- upgraded to 5.0 - dump all patches. Reapply later if needed.
- added the NEWS file to the %%doc files
- don't delete files which doesn't get installed (readline, texinfo)
- let build system handle stripping and gzipping
- don't delete libmmalloc
- apply patch from jakub@redhat.com to make it build on SPARC

* Fri Apr 28 2000 Matt Wilson <msw@redhat.com>
- rebuilt against new ncurses

* Tue Mar  7 2000 Jeff Johnson <jbj@redhat.com>
- rebuild for sparc baud rates > 38400.

* Tue Feb  8 2000 Jakub Jelinek <jakub@redhat.com>
- fix core file handling on i386 with glibc 2.1.3 headers

* Fri Jan 14 2000 Jakub Jelinek <jakub@redhat.com>
- fix reading registers from core on sparc.
- hack around build problems on i386 with glibc 2.1.3 headers

* Thu Oct 7 1999 Jim Kingdon
- List files to install in /usr/info specifically (so we don't pick up
things like info.info from GDB snapshots).

* Thu Oct 7 1999 Jim Kingdon
- Update GDB to 19991004 snapshot.  This eliminates the need for the
sigtramp, sparc, xref, and threads patches.  Update sparcmin patch.

* Mon Aug 23 1999 Jim Kingdon
- Omit readline manpage.

* Tue Aug 7 1999 Jim Kingdon
- Remove H.J. Lu's patches (they had been commented out).
- Add sigtramp patch (from gdb.cygnus.com) and threads patch (adapted
from code fusion CD-ROM).

* Wed Apr 14 1999 Jeff Johnson <jbj@redhat.com>
- merge H.J. Lu's patches into 4.18.

* Mon Apr 05 1999 Cristian Gafton <gafton@redhat.com>
- updated the kern22 patch with stuff from davem

* Thu Apr  1 1999 Jeff Johnson <jbj@redhat.com>
- sparc with 2.2 kernels no longer uses sunos ptrace (davem)

* Sun Mar 21 1999 Cristian Gafton <gafton@redhat.com>
- auto rebuild in the new build environment (release 3)

* Mon Mar  8 1999 Jeff Johnson <jbj@redhat.com>
- Sparc fiddles for Red Hat 6.0.
